==> gd32f1-0.2.0.crate: gd32f1-0.2.0/src/gd32f150/fmc/wp.rs <==
#[doc = "Register `WP` reader"]
pub struct R(crate::R<WP_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WP_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<WP_SPEC>> for R {
    fn from(reader: crate::R<WP_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `OB_WP` reader - Store OB_WP\\[15:0\\]
of option byte block after system reset"]
pub struct OB_WP_R(crate::FieldReader<u16, u16>);
impl OB_WP_R {
    pub(crate) fn new(bits: u16) -> Self {
        OB_WP_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for OB_WP_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:15 - Store OB_WP\\[15:0\\]
of option byte block after system reset"]
    #[inline(always)]
    pub fn ob_wp(&self) -> OB_WP_R {
        OB_WP_R::new((self.bits & 0xffff) as u16)
    }
}
#[doc = "Write protection register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wp](index.html) module"]
pub struct WP_SPEC;
impl crate::RegisterSpec for WP_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wp::R](R) reader structure"]
impl crate::Readable for WP_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets WP to value 0"]
impl crate::Resettable for WP_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f150/fmc/wp.rs <==
#[doc = "Register `WP` reader"]
pub struct R(crate::R<WP_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WP_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<WP_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<WP_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `OB_WP` reader - Store OB_WP\\[15:0\\]
of option byte block after system reset"]
pub struct OB_WP_R(crate::FieldReader<u16, u16>);
impl OB_WP_R {
    pub(crate) fn new(bits: u16) -> Self {
        OB_WP_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for OB_WP_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:15 - Store OB_WP\\[15:0\\]
of option byte block after system reset"]
    #[inline(always)]
    pub fn ob_wp(&self) -> OB_WP_R {
        OB_WP_R::new((self.bits & 0xffff) as u16)
    }
}
#[doc = "Write protection register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wp](index.html) module"]
pub struct WP_SPEC;
impl crate::RegisterSpec for WP_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wp::R](R) reader structure"]
impl crate::Readable for WP_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets WP to value 0"]
impl crate::Resettable for WP_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
